@@ -1,6 +1,6 @@
 // Filename: component_config.rs
-// Version:	 0.9
-// Date:	 15-09-2021 (DD-MM-YYYY)
+// Version:	 0.10
+// Date:	 24-09-2021 (DD-MM-YYYY)
 // Library:  gpcas_cpu_model
 //
 // Copyright (c) 2021 Kai Rese
@@ -23,8 +23,12 @@
 #[doc(hidden)]
 mod cache;
 #[doc(hidden)]
+mod decoder;
+#[doc(hidden)]
 mod fetch;
 #[doc(hidden)]
+mod load_store_unit;
+#[doc(hidden)]
 mod memory_controller;
 #[doc(hidden)]
 mod pipeline;
@@ -34,6 +38,7 @@ mod register_file;
 mod scheduler;
 
 pub use cache::{CacheConfig, CacheType};
+pub use decoder::DecodeConfig;
 pub use fetch::FetchConfig;
 pub use memory_controller::MemoryControllerConfig;
 pub use pipeline::{AluCapabilities, PipelineConfig};
