@@ -18,7 +18,10 @@
 // License along with this program. If not, see
 // <https://www.gnu.org/licenses/>.
 
+use serde::{Deserialize, Serialize};
+
 /// The properties of a scheduler.
+#[derive(Default, Deserialize, Serialize)]
 pub struct SchedulerConfig {
     /// The identification number. Used for connecting pipelines.
     pub id: usize,
