@@ -1,6 +1,6 @@
 // Filename: lib.rs
-// Version:	 0.8
-// Date:	 15-09-2021 (DD-MM-YYYY)
+// Version:	 0.9
+// Date:	 24-09-2021 (DD-MM-YYYY)
 // Library:  gpcas_cpu_model
 //
 // Copyright (c) 2021 Kai Rese
@@ -44,8 +44,10 @@ pub struct CPUModel {
     pub memory_controller_config: component_config::MemoryControllerConfig,
     /// Caches of the memory hierarchy.
     pub caches: Vec<component_config::CacheConfig>,
-    /// The amount of parallel decoders.
-    pub decoder_count: usize,
+    /// Configuration for the decode stage of the front end.
+    pub decode_config: component_config::DecodeConfig,
+    /// How many cycles the dispatch unit needs to dispatch an instruction.
+    pub dispatch_cycle_count: usize,
     /// Configuration of the register file.
     pub reg_file_config: component_config::RegisterFileConfig,
     /// Configuration of schedulers.
@@ -90,7 +92,8 @@ impl CPUModel {
             fetch_config: component_config::FetchConfig::default(),
             memory_controller_config: component_config::MemoryControllerConfig::default(),
             caches: Vec::new(),
-            decoder_count: 1,
+            decode_config: component_config::DecodeConfig::default(),
+            dispatch_cycle_count: 0,
             reg_file_config: Default::default(),
             schedulers: Vec::new(),
             pipelines: Vec::new(),
@@ -131,9 +134,11 @@ impl InstructionLatencies {
 
 impl GpcasFileStruct for CPUModel {
     const FILE_IDENTIFIER: &'static str = "gpcas::cpu_model";
-    const CURRENT_FILE_VERSION: usize = 1;
-    const COMPATIBLE_VERSIONS: &'static [(usize, DeserializeFunction<CPUModel>)] =
-        &[(0, deserialize_upgrade_from::<legacy::CPUModelV0, CPUModel>)];
+    const CURRENT_FILE_VERSION: usize = 2;
+    const COMPATIBLE_VERSIONS: &'static [(usize, DeserializeFunction<Self>)] = &[
+        (0, deserialize_upgrade_from::<legacy::v0::CPUModel, Self>),
+        (1, deserialize_upgrade_from::<legacy::v1::CPUModel, Self>),
+    ];
 }
 
 /// The default latency in clock cycles for all instruction types.
